/hg/gfx-test: Added new tests and new helper methods into BitBlt...

ptisnovs at icedtea.classpath.org ptisnovs at icedtea.classpath.org
Mon Jun 9 10:00:59 UTC 2014


changeset 9a62e5957854 in /hg/gfx-test
details: http://icedtea.classpath.org/hg/gfx-test?cmd=changeset;node=9a62e5957854
author: Pavel Tisnovsky <ptisnovs at redhat.com>
date: Mon Jun 09 12:01:49 2014 +0200

	Added new tests and new helper methods into BitBltUsingBgColor.


diffstat:

 ChangeLog                                          |    5 +
 src/org/gfxtest/testsuites/BitBltUsingBgColor.java |  133 ++++++++++++++------
 2 files changed, 97 insertions(+), 41 deletions(-)

diffs (386 lines):

diff -r c085da818b20 -r 9a62e5957854 ChangeLog
--- a/ChangeLog	Fri Jun 06 12:06:24 2014 +0200
+++ b/ChangeLog	Mon Jun 09 12:01:49 2014 +0200
@@ -1,3 +1,8 @@
+2014-06-09  Pavel Tisnovsky  <ptisnovs at redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	Added new tests and new helper methods into BitBltUsingBgColor.
+
 2014-06-06  Pavel Tisnovsky  <ptisnovs at redhat.com>
 
 	* src/org/gfxtest/testsuites/CAGOperationsOnTwoOverlappingRectangles.java:
diff -r c085da818b20 -r 9a62e5957854 src/org/gfxtest/testsuites/BitBltUsingBgColor.java
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Fri Jun 06 12:06:24 2014 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Mon Jun 09 12:01:49 2014 +0200
@@ -541,7 +541,7 @@
     }
 
     /**
      * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -551,14 +551,14 @@
      *            background color
      * @return test result status - PASSED, FAILED or ERROR
      */
-    private TestResult doBitBltDiagonalCheckerBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
+    private TestResult doBitBltCheckerBufferedImageTypeCustom(TestImage image, Graphics2D graphics2d,
                     Color backgroundColor)
     {
-        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, backgroundColor);
-    }
-
-    /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR
+        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_CUSTOM, backgroundColor);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -568,6 +568,23 @@
      *            background color
      * @return test result status - PASSED, FAILED or ERROR
      */
+    private TestResult doBitBltDiagonalCheckerBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d,
+                    Color backgroundColor)
+    {
+        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, backgroundColor);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
+     *
+     * @param image
+     *            image to be used as a destination for BitBlt-type operations
+     * @param graphics2d
+     *            graphics canvas
+     * @param backgroundColor
+     *            background color
+     * @return test result status - PASSED, FAILED or ERROR
+     */
     private TestResult doBitBltDiagonalCheckerBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d,
                     Color backgroundColor)
     {
@@ -575,7 +592,7 @@
     }
 
     /**
      * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -585,14 +602,14 @@
      *            background color
      * @return test result status - PASSED, FAILED or ERROR
      */
-    private TestResult doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(TestImage image, Graphics2D graphics2d,
+    private TestResult doBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d,
                     Color backgroundColor)
     {
         return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, backgroundColor);
     }
 
     /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -609,7 +626,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB_PRE
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -619,14 +636,14 @@
      *            background color
      * @return test result status - PASSED, FAILED or ERROR
      */
-    private TestResult doBitBltDiagonalCheckerBufferedImageTypeIntARGBPre(TestImage image, Graphics2D graphics2d,
+    private TestResult doBitBltDiagonalCheckerBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d,
                     Color backgroundColor)
     {
         return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, backgroundColor);
     }
 
     /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -643,7 +660,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -660,7 +677,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -677,7 +694,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_GRAY
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -694,7 +711,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_INDEXED
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -711,7 +728,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -728,7 +745,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_565_RGB
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -745,7 +762,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_GRAY
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -762,7 +779,7 @@
     }
 
     /**
      * Test basic BitBlt operation for grid buffered image with type TYPE_3BYTE_BGR
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -772,14 +789,14 @@
      *            background color
      * @return test result status - PASSED, FAILED or ERROR
      */
-    private TestResult doBitBltGridBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
+    private TestResult doBitBltDiagonalCheckerBufferedImageTypeCustom(TestImage image, Graphics2D graphics2d,
                     Color backgroundColor)
     {
-        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, backgroundColor);
-    }
-
-    /**
-     * Test basic BitBlt operation for grid buffered image with type TYPE_4BYTE_ABGR
+        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_CUSTOM, backgroundColor);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -789,6 +806,23 @@
      *            background color
      * @return test result status - PASSED, FAILED or ERROR
      */
+    private TestResult doBitBltGridBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d,
+                    Color backgroundColor)
+    {
+        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, backgroundColor);
+    }
+
+    /**
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
+     *
+     * @param image
+     *            image to be used as a destination for BitBlt-type operations
+     * @param graphics2d
+     *            graphics canvas
+     * @param backgroundColor
+     *            background color
+     * @return test result status - PASSED, FAILED or ERROR
+     */
     private TestResult doBitBltGridBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d,
                     Color backgroundColor)
     {
@@ -796,7 +830,7 @@
     }
 
     /**
      * Test basic BitBlt operation for grid buffered image with type TYPE_4BYTE_ABGR
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -806,14 +840,14 @@
      *            background color
      * @return test result status - PASSED, FAILED or ERROR
      */
-    private TestResult doBitBltGridBufferedImageType4ByteABGRPre(TestImage image, Graphics2D graphics2d,
+    private TestResult doBitBltGridBufferedImageType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d,
                     Color backgroundColor)
     {
         return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, backgroundColor);
     }
 
     /**
-     * Test basic BitBlt operation for grid buffered image with type TYPE_INT_ARGB
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -830,7 +864,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for grid buffered image with type TYPE_INT_ARGB_PRE
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -840,14 +874,14 @@
      *            background color
      * @return test result status - PASSED, FAILED or ERROR
      */
-    private TestResult doBitBltGridBufferedImageTypeIntARGBPre(TestImage image, Graphics2D graphics2d,
+    private TestResult doBitBltGridBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d,
                     Color backgroundColor)
     {
         return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, backgroundColor);
     }
 
     /**
-     * Test basic BitBlt operation for grid buffered image with type TYPE_INT_BGR
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -864,7 +898,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for grid buffered image with type TYPE_INT_RGB
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -881,7 +915,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for grid buffered image with type TYPE_BYTE_BINARY
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -898,7 +932,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for grid buffered image with type TYPE_BYTE_GRAY
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -915,7 +949,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for grid buffered image with type TYPE_BYTE_INDEXED
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -932,7 +966,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for grid buffered image with type TYPE_USHORT_555_RGB
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -949,7 +983,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for grid buffered image with type TYPE_USHORT_565_RGB
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -966,7 +1000,7 @@
     }
 
     /**
-     * Test basic BitBlt operation for grid buffered image with type TYPE_USHORT_GRAY
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -983,7 +1017,7 @@
     }
 
     /**
      * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_3BYTE_BGR
      *
      * @param image
      *            image to be used as a destination for BitBlt-type operations
@@ -993,6 +1027,23 @@
      *            background color
      * @return test result status - PASSED, FAILED or ERROR
      */
+    private TestResult doBitBltGridBufferedImageTypeCustom(TestImage image, Graphics2D graphics2d,
+                    Color backgroundColor)
+    {
+        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_CUSTOM, backgroundColor);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
+     *
+     * @param image
+     *            image to be used as a destination for BitBlt-type operations
+     * @param graphics2d
+     *            graphics canvas
+     * @param backgroundColor
+     *            background color
+     * @return test result status - PASSED, FAILED or ERROR
+     */
     private TestResult doBitBltDiagonalGridBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
                     Color backgroundColor)
     {
@@ -541,7 +541,7 @@
 
     /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_CUSTOM}.
      *
      * @param image
@@ -575,7 +592,7 @@
 
     /**
-     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
      *
      * @param image
@@ -762,7 +779,7 @@
 
     /**
-     * Test basic BitBlt operation for grid buffered image with type TYPE_3BYTE_BGR
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_CUSTOM}.
      *
      * @param image
@@ -796,7 +830,7 @@
 
     /**
-     * Test basic BitBlt operation for grid buffered image with type TYPE_4BYTE_ABGR
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
      *
      * @param image
@@ -983,7 +1017,7 @@
 
     /**
-     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_3BYTE_BGR
+     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_CUSTOM}.
      *
      * @param image


More information about the distro-pkg-dev mailing list